#ifndef CONFIGURATION_H
#define CONFIGURATION_H

/*
 *  This is the configuration file for the RepRap Motherboard microcontroller.
 *  Set values in it to match your RepRap machine.
*/

// Here are the Motherboard codes: 0 - 1 - 3 got ripped, and the only available choice is 2 for RepRap Motherboard with RS485 extruders
#define MOTHERBOARD 2

// Axis scaling in stepper-motor steps per mm of movement

#define X_STEPS_PER_MM   26.6667
#define X_STEPS_PER_INCH (X_STEPS_PER_MM*INCHES_TO_MM) // *RO
#define INVERT_X_DIR 0

#define Y_STEPS_PER_MM   26.6667
#define Y_STEPS_PER_INCH (Y_STEPS_PER_MM*INCHES_TO_MM) // *RO
#define INVERT_Y_DIR 0

#define Z_STEPS_PER_MM   1066.667
#define Z_STEPS_PER_INCH (Z_STEPS_PER_MM*INCHES_TO_MM) // *RO
#define INVERT_Z_DIR 0

// Stepper-driven extruder ONLY E_STEPS_PER_MM is the number of steps needed to extrude 1mm out of the nozzle.  E0 for extruder 0; E1 for extruder 1, and so on.
//#define E0_STEPS_PER_MM   21.75      // before SF40 MTG 55:11 1600 steps 5mm dia of engaging point 0.4 nozzle
#define E0_STEPS_PER_MM   542.0        // 271 MTG 542.0=repsnapper100/100 half is SF41 for 1600steps 39/11 6.5mm dia hobbed bolt 


//our maximum feedrates in mm/minute
#define FAST_XY_FEEDRATE 3000.0
#define FAST_Z_FEEDRATE  40.0
// Comment out the next line to turn accelerations off
//#define ACCELERATION_ON
#define SLOW_XY_FEEDRATE 400.0 // Speed from which to start accelerating
#define SLOW_Z_FEEDRATE 25.0



// Set these to 1 to disable an axis when it's not being used. Extruder cant be disabled. Usually only Z is disabled when not in use, disabling X or Y causes poor-quality build. Inertia causes overshoot if the motors are not powered up.
#define DISABLE_X 0
#define DISABLE_Y 0
#define DISABLE_Z 0

// Set to one if the axis opto-sensor outputs inverting (ie: 1 means open, 0 means closed) RepRap opto endstops with H21LOI sensors are not inverting; ones with H21LOB are inverting.
#define X_ENDSTOP_INVERTING true
#define Y_ENDSTOP_INVERTING true
#define Z_ENDSTOP_INVERTING true

// Set 1s where you have endstops; 0s where you don't. Both Darwin and Mendel have MIN endstops, but not MAX ones.
#define ENDSTOPS_MIN_ENABLED 1
#define ENDSTOPS_MAX_ENABLED 0

// Set to 1 if enable pins are inverting For RepRap stepper boards version 1.x the enable pins are *not* inverting. For RepRap stepper boards version 2.x and above the enable pins are inverting.
#define INVERT_ENABLE_PINS 1

#if INVERT_ENABLE_PINS == 1  // *RO
#define ENABLE_ON LOW        // *RO
#else                        // *RO
#define ENABLE_ON HIGH       // *RO
#endif                       // *RO



//**********************************************************************************************
// Normally unchanged stuff
//*********************************************************************************************

// The width of Henry VIII's thumb (or something).
#define INCHES_TO_MM 25.4 // *RO

// The number of real extruders in this machine
#define EXTRUDER_COUNT 1

#define MY_NAME 'H'           // Byte representing the name of this device
#define E0_NAME '0'           // Byte representing the name of extruder 0
#define E1_NAME '1'           // Byte representing the name of extruder 1
#define RS485_MASTER  1       // Motherboard is the master

// The speed at which to talk with the host computer; default is 19200
#define HOST_BAUD 19200 // *RO

//our command string length
#define COMMAND_SIZE 128 // *RO

// Our response string length
#define RESPONSE_SIZE 256 // *RO ORIGINAL 256 MODIFICAT PT REPSNALLER LA 128

// The size of the movement buffer
#define BUFFER_SIZE 4 // *RO ORIGINAL 4

// Number of microseconds between timer interrupts when no movement is happening
#define DEFAULT_TICK (long)1000 // *RO

// What delay() value to use when waiting for things to free up in milliseconds
#define WAITING_DELAY 1 // *RO

// The number of mm below which distances are insignificant (one tenth the
// resolution of the machine is the default value).
#define SMALL_DISTANCE 0.01 // *RO

// Useful to have its square
#define SMALL_DISTANCE2 (SMALL_DISTANCE*SMALL_DISTANCE) // *RO

// RS485 settings found in intercom.h: RS485_BAUD 1000000 and RS485_BUF_LEN 20 (change 20 to 40 in case of rs485 specific comm issues)

//**********************************************************************************************
// You probably only want to edit things below this line if you really really know what you are doing...
//*********************************************************************************************

void delayMicrosecondsInterruptible(unsigned int us);

// Inline interrupt control functions

inline void enableTimerInterrupt() 
{
   TIMSK1 |= (1<<OCIE1A);
}
	
inline void disableTimerInterrupt() 
{
     TIMSK1 &= ~(1<<OCIE1A);
}
        
inline void setTimerCeiling(unsigned int c) 
{
    OCR1A = c;
}

inline void resetTimer()
{
  TCNT2 = 0;
}

#endif


